Improve this Doc

# Error: $controller:noscp
Missing $scope object

    Cannot export controller '{0}' as '{1}'! No $scope object provided via `locals`.

## Description

This error occurs when $controller service is called in order to instantiate a new controller but no scope is provided via `$scope` property of the locals map.

Example of incorrect usage that leads to this error:

    $controller(MyController);
    //or
    $controller(MyController, {scope: newScope});

To fix the example above please provide a scope (using the `$scope` property in the locals object) to the $controller call:

    $controller(MyController, {$scope: newScope});

Please consult the $controller service api docs to learn more.